pub(crate) struct EncodedRequest {
header: String,
body: RequestBody,
}Expand description
The encoding of a http request.
This type is meant to avoid copies in the case where we want to upload a document in the body of a request.
Fields
header: StringThe request header. We generate this fresh for each request.
body: RequestBodyThe request body. This can be shared by multiple requests (and generally is, for uploads).
Implementations
Sourceimpl EncodedRequest
impl EncodedRequest
Sourcepub(crate) fn from_header(header: String) -> Self
pub(crate) fn from_header(header: String) -> Self
Create a new EncodedRequest from a header.
Sourcepub(crate) fn set_body(&mut self, body: RequestBody)
pub(crate) fn set_body(&mut self, body: RequestBody)
Set the body in this request.