#[non_exhaustive]pub enum AnonymizedRequest {
Anonymized,
Direct,
}Expand description
Flag to declare whether a request is always anonymized or not.
This is used by tor-dirclient to control whether other deanonymizing metadata might be added to the request (eg in request headers): Some requests (like those to download onion service descriptors) are always anonymized, and should never be sent in a way that leaks information about our settings or configuration.
It is up to the caller of tor-dirclient to ensure that
-
every request whose anonymization status is
AnonymizedRequest::Directis sent only over non-anonymous connections.(Sending an
AnonymizedRequest::Directrequest over an anonymized connection would weaken the connection’s anonymity, and can therefore weaken the anonymity of user traffic sharing the same circuit.) -
every request whose anonymization status is
AnonymizedRequest::Anonymizedis sent over only anonymous connections (ie, multi-hop circuits).(Sending an
AnonymizedRequest::Anonymizedrequest over a direct connection would directly reveal user behaviour data to the directory server.)
TODO the calling code cannot easily be sure to get this right this because the anonymization status is a run-time property and the choice of connection kind is statically defined in the calling code. (Perhaps this could be checked in tests?)
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Anonymized
This request’s content or semantics reveals or is correlated with sensitive information.
For example, requests for hidden service descriptors reveal which hidden services the client is connecting to.
The request must be sent over an anonymous circuit by the caller
and no additional deanonymizing information should be added to it by tor-dirclient.
(For example, no client-version-specific information should be
sent in HTTP headers when the request is made.)
Direct
Making this request does not reveal anything sensitive, nor any user behaviour.
The request body is uncorrelated with such things as the websites the user might visit, the onion services the user is visiting or running, etc.
For example, requests for all router microdescriptors are made by all clients, so which microdescriptor(s) are requested reveals nothing to any attacker.
tor-dirclient is allowed to add include information about our capabilities when sending this request. The request must not be sent over an anonymous circuit by the caller (at least, not one used for anything else).