digest_list_stringify

Function digest_list_stringify 

fn digest_list_stringify<'d, D, DL, EF>(
    digests: DL,
    encode: EF,
    sep: &str,
) -> Option<String>
where DL: IntoIterator<Item = &'d D> + 'd, D: PartialOrd + Ord + 'd, EF: Fn(&'d D) -> String,
Convert a list of digests in some format to a string, for use in a request

The digests DL will be sorted, converted to strings with EF, separated with sep, and returned as an fresh String.

If the digests list is empty, returns None instead.