pub struct ConsensusRequest { /* private fields */ }
A Request for a consensus directory.

Implementations

Create a new request for a consensus directory document.

Add id to the list of authorities that this request should say we believe in.

Add d to the list of consensus digests this request should say we already have.

Set the publication time we should say we have for our last consensus to when.

Return a slice of the consensus digests that we’re saying we already have.

Return an iterator of the authority identities that this request is saying we believe in.

Return the date we’re reporting for our most recent consensus.

Tell the directory client that we should abort the request early if the directory’s clock skew exceeds certain limits.

The max_fast parameter is the most fast that we’re willing to be with respect to the directory (or in other words, the most slow that we’re willing to let the directory be with respect to us).

The max_slow parameter is the most slow that we’re willing to be with respect to the directory ((or in other words, the most slow that we’re willing to let the directory be with respect to us).