fn digest_list_stringify<'d, D, DL, EF>(
digests: DL,
encode: EF,
sep: &str,
) -> Option<String>Expand description
Convert a list of digests in some format to a string, for use in a request
The digests DL will be sorted, converted to strings with EF,
separated with sep, and returned as an fresh String.
If the digests list is empty, returns None instead.