Requestable

Trait Requestable 

pub trait Requestable: RequestableInner {
    // Provided method
    fn debug_request(&self) -> DisplayRequestable<'_, Self>
       where Self: Sized { ... }
}
A request for an object that can be served over the Tor directory system.

Provided Methods

fn debug_request(&self) -> DisplayRequestable<'_, Self>
where Self: Sized,

Return a wrapper around this Requestable that implements Debug, and whose output shows the actual HTTP request that will be generated.

The format is not guaranteed to be stable.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: RequestableInner> Requestable for T